<?php
/*
  Plugin Name: E-Abi TCPDF and FPDI dependency plugin
  Plugin URI: https://en.e-abi.ee/
  Description: Adds setasign/fpdi and tecnickcom/tcpdf dependencies to Wordpress
  Version: 1.0.1
  Author: Matis Halmann, Aktsiamaailm LLC
  Copyright: (c) Aktsiamaailm LLC
  License: GNU General Public License (GPL) version 3
  License URI: http://www.gnu.org/licenses/gpl-3.0.txt
  WC requires at least: 3.0.0
  WC tested up to: 5.0.0

 *
 */

/*
 *  *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the OpenGPL v3 license (GNU Public License V3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@e-abi.ee so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade this module to newer
 * versions in the future.
 *
 * @category   Wordpress Dependency Library
 * @package    FPDI And TCPDF libraries
 * @copyright  Copyright (c) 2023 Aktsiamaailm LLC (http://en.e-abi.ee/)
 * @license    http://www.gnu.org/licenses/gpl-3.0.txt  GNU Public License V3.0
 * @author     Matis Halmann
 * 

 */


// Security check
if (!defined('ABSPATH')) {
    exit;
}


if (!class_exists('Eabi_Postoffice_Pdf_Dependency_Loader')) {
    class Eabi_Postoffice_Pdf_Dependency_Loader {


        public function __construct() {
//            $this->load_dependencies();
            add_filter('plugins_loaded', [$this, 'load_dependencies']);


        }


        public function load_dependencies() {
            $this->loadTCPDF();
            $this->loadFPDI();



        }

        protected function loadTCPDF() {
            $filePath = 'vendor/tecnickcom/library-tcpdf';
            if (class_exists('TCPDF')) {
                //do nothing if the class is already loaded
                return;
            }

            $tcpdf_include_dirs = array(
                realpath(dirname(__FILE__) . '/' . $filePath. '/tcpdf.php'),// True source file
                realpath('../tcpdf.php'),// Relative from $PWD
                '/usr/share/php/tcpdf/tcpdf.php',
                '/usr/share/tcpdf/tcpdf.php',
                '/usr/share/php-tcpdf/tcpdf.php',
                '/var/www/tcpdf/tcpdf.php',
                '/var/www/html/tcpdf/tcpdf.php',
                '/usr/local/apache2/htdocs/tcpdf/tcpdf.php'
            );
            foreach ($tcpdf_include_dirs as $tcpdf_include_path) {
                if (@file_exists($tcpdf_include_path)) {
                    require_once($tcpdf_include_path);
                    break;
                }
            }


        }


        protected function loadFPDI() {
            $filePath = 'vendor/setasign/library-fpdi';
            if (class_exists('setasign\Fpdi\FpdiException')) {
                return;
            }
            require_once(realpath(dirname(__FILE__) . '/' . $filePath. '/src/autoload.php'));

        }


    }



    add_action('before_woocommerce_init', function () {
        if (class_exists("\Automattic\WooCommerce\Utilities\FeaturesUtil")) {
            \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__,
                true);
        }
    });


    new Eabi_Postoffice_Pdf_Dependency_Loader();


}